## Release Notes for 1.5.4

Released on 4 January 2022

This is a bugfix release that fixes an issues with renderring HTML from a document, either in the viewer or the build tool, when there is a greater or lesser than symbol in a text block that isn't a plain text paragraph, like for instance a comment or a heading. Any such document would fail to render.

See also the Releases page.

## Release Notes for 1.5.3

Released on 31 December 2021

This is a bugfix release that fixes two cosmetic issues. The first fix resolves and issue with the emphasis of partition or chapter items in the project tree not changing when the item is changed to a scene item. The second fix changes how the Create Root Folder submenu works. Instead of disabling the menu entries that are no longer available, they are instead removed. Disabled menu entries are not displayed correctly in all colour themes.

## Release Notes for 1.5.2

Released on 12 December 2021

This is a bugfix release that fixes two issues. The first is an issue with an error in the HTML output if a paragraph has alignment or indentation tags while at the same time containing emphasised text. The second is an issue where the application cannot load a project with spell checking enabled if there is something wrong with the spell check package.

## Release Notes for 1.5.1

Released on 23 October 2021

This is a bugfix release that fixes two issues. One related to the Project Details dialog missing its translated labels for non-English languages, and a fix concerning switching focus to the project tree when the Novel tab is visible. If the Novel tab is selected, the focus shift now correctly gives focus to the Novel tree.

## Release Notes for 1.5

Released on 19 September 2021

This release reduces the number of document layouts from eight to two. The full list of changes is described in the "Novel Document Layouts" section below.

Due to this change, the main project file for your projects will need to be updated when you first open them in novelWriter 1.5. This is done automatically. The index is updated as well. When this conversion is done, you can no longer open the project in an older version of novelWriter.

You may also have to make a handful of changes in your novel documents as novelWriter will not make any automated changes to your actual text. However, the changes are minimal and in any case only affects the way your manuscript looks like when exported via the Build Novel Project tool. These details are also described below.

From this release on, Debian packages will be provided for Mint, Ubuntu and Debian users. A new PPA has also been created. This allows users to install and update novelWriter automatically on these Linux distros.

#### Novel Document Layouts

The main change in this release is the significant simplification of document layouts. Previously, there were seven different layouts available for novel documents, in addition to the one layout for project notes. The original intention of these layouts were partially to define some default formatting behaviour when exporting your project, and partially as a way to indicate whether a specific document was a partition, chapter or scene.

With this release, all the seven layouts for novel documents have been merged into a single layout called simply "Novel Document". The other layout, "Project Note", remains unchanged. The functionality provided by the various novel layouts have been implemented in other ways, and a few new formatting codes have been added to accommodate the formatting functionality lost with the removal of the layouts. They are all available in the Format and Insert menus.

The changes you need to make to your project should be limited to altering a handful of titles and maybe insert a page break code here and there. The only title formats you need to update are those for the main novel title and for your unnumbered chapters, if you have any.

Novel titles need to be altered from "# Novel Title" to "#! Novel Title" and unnumbered chapters from "## Chapter Name" or "## *Chapter Name" to "##! Chapter Name". That is all. For inserting page breaks, you can add a single line with the command "[NEW PAGE]" where you want the break to be inserted. As before, page breaks are automatically inserted in front of all partition and chapter titles.

You will find these changes described in more detail in the documentation in the "Format 1.3 Changes" section.

#### GUI Changes

Due to the above changes, the GUI has been altered a bit. The main changes are in the project tree. These changes are also reflected in the details panel below the project tree, and to a lesser extent in the Outline tab.

The layouts were previously a way to indicate the purpose of a specific novel document, like whether it was a chapter or scene. With these layouts gone, the distinction is instead indicated by other visual means.

The project index will now record the level of the first header of your document, and select a different icon for documents with a partition, chapter or scene header. These are colour coded as green, red, and blue respectively. The project notes have also received a new icon, with a yellow colour code. Due to this change, the grey icon themes have been removed.

In addition, novel documents with a partition or chapter header will have the document label viewed as bold and underlined. This feature can be disabled in Preferences if you want a cleaner look in the project tree.

#### Other Changes

Several improvements have been made to the project index, which means the index will be automatically rebuilt when you open a project for the first time in the new version. You will get a notification about this.

The ODT export tool has also been improved. The code that writes out text paragraphs has been rewritten and now conforms more closely to the Open Document standard. Most of these improvements will not be noticeable to you as a user, but you may notice that the exported document will now allow multiple consecutive spaces. Previously, two spaces, or more, would be concatenated into a single space in the exported document.

The internal spell check tool has been removed. If you want spell checking, you must install the Spell Enchant tool. The internal spell checker was only ever added because the Python package for Spell Enchant was not available on 64-bit Windows. This was corrected over a year ago. The main issue with the internal spell checker was that it only included English, and the large dictionary files had to be shipped with novelWriter.

Finally, a PDF version of the documentation should now be shipped with your install package. If it is available, a "User Manual (PDF)" option should be visible in the Help menu. This should give you access to the documentation also when you don't have an active internet connection.